import fs from "fs";
import pdf_converter from "html-pdf";
import path from 'path';
import { Stream } from 'stream';

/**
 * This class is responsible for all things pdf creation.
 * This uses the html templates from src/templates.
 */
export class PdfCreator {
    private templateDir = path.join(__dirname, '/templates');

    //TODO: Accept the runner class
    public async generateSponsoringContract(): Promise<Pdf> {
        let template = fs.readFileSync(`${this.templateDir}/sponsoring_contract.html`, 'utf8');
        template = template.replace("{{Runner Name}}", "lelele");
        return new Pdf(await pdf_converter.create(template, { format: "A5", orientation: "landscape" }));
    }

}

/**
 * This class is a wrapper for the pdf objects created by html-pdf.
 * It offers typed conversion to Buffer and Stream.
 */
export class Pdf {
    content: any;

    constructor(pdf: any) {
        this.content = pdf;
    }

    /**
     * Promise wrapper function that resolves the toBuffer promise for pdf generation.
     */
    public async toBuffer(): Promise<Buffer> {
        let promise = await new Promise<Buffer>((resolve, reject) => {
            this.content.toBuffer(function (err, buffer: Buffer) {
                resolve(buffer);
            });
        });
        return await promise;
    }

    /**
     * Promise wrapper function that resolves the toStream promise for pdf generation.
     */
    public async toStream(): Promise<Stream> {
        let promise = await new Promise<Stream>((resolve, reject) => {
            this.content.toStream(function (err, stream: Stream) {
                resolve(stream);
            });
        });
        return await promise;
    }
}